# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-10-09 09:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('speedinfo', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='viewprofiler',
            name='sql_total_count',
            field=models.PositiveIntegerField(default=0, verbose_name=b'SQL total queries count'),
        ),
        migrations.AddField(
            model_name='viewprofiler',
            name='sql_total_time',
            field=models.FloatField(default=0, verbose_name=b'SQL total time'),
        ),
    ]
