{% extends "admin/change_list.html" %}

{% block object-tools %}
    <ul class="object-tools">
        <li>
            <a href="{% url "admin:speedinfo-profiler-switch" %}"
                {% if profiler_is_on %}class="turned-on">Turn off{% else %}class="turned-off">Turn on{% endif %}
            </a>
        </li>
        <li>
            <a href="{% url "admin:speedinfo-profiler-export" %}">Export .CSV</a>
        </li>
        <li>
            <a href="{% url "admin:speedinfo-profiler-reset" %}" onclick="return confirm('Are you sure?')">Reset</a>
        </li>
    </ul>
{% endblock %}
