# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2018-04-09 17:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('speedinfo', '0003_auto_20171023_1722'),
    ]

    operations = [
        migrations.AlterField(
            model_name='viewprofiler',
            name='anon_calls',
            field=models.PositiveIntegerField(default=0, verbose_name='Anonymous calls'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='cache_hits',
            field=models.PositiveIntegerField(default=0, verbose_name='Cache hits'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='method',
            field=models.CharField(max_length=8, verbose_name='HTTP method'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='sql_total_count',
            field=models.PositiveIntegerField(default=0, verbose_name='SQL total queries count'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='sql_total_time',
            field=models.FloatField(default=0, verbose_name='SQL total time'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='total_calls',
            field=models.PositiveIntegerField(default=0, verbose_name='Total calls'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='total_time',
            field=models.FloatField(default=0, verbose_name='Total time'),
        ),
        migrations.AlterField(
            model_name='viewprofiler',
            name='view_name',
            field=models.CharField(max_length=255, verbose_name='View name'),
        ),
    ]
